==> haskell-xml-hamlet-0.5.0.2-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-HqjeOQuSN7H56mYuWq8037
key:                  xml-hamlet-0.5.0.2-HqjeOQuSN7H56mYuWq8037
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  8b83de7609c6daab67a21fd087bcbc99
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.0.2/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-HqjeOQuSN7H56mYuWq8037
depends:
    base-4.15.1.0 containers-0.6.4.1 parsec-3.1.14.0
    shakespeare-2.0.29-HGdXmtuljC7BZgPQ5M9GE4 template-haskell-2.17.0.0
    text-1.2.5.0 xml-conduit-1.9.1.1-38hIhSLG9kn1V4KGyCGsyf

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.5.0.2-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-EaTcFIEvuoF4o2RHburyc0
key:                  xml-hamlet-0.5.0.2-EaTcFIEvuoF4o2RHburyc0
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  bd6171c545fc790ff047ad41eff14502
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.0.2/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-EaTcFIEvuoF4o2RHburyc0
depends:
    base-4.15.1.0 containers-0.6.4.1 parsec-3.1.14.0
    shakespeare-2.0.30-GWfzk65hwKsEOT6cQOeXMq template-haskell-2.17.0.0
    text-1.2.5.0 xml-conduit-1.9.1.1-6djIv4jKfGKGPryVECh7F

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
